Description: civ.club; Общение и соревнования игроков в Civilization V на русском языке; Цивилизация 5 - моды, юниты, карты; wiki-справочник по игре; турниры, игры онлайн
Keywords: civ.club,игра,Цивилизация,game,Civilization,civ5,Colonization,Колонизация,мод,моды,цива,сетевая,стратегические,походовая,цивилопедия,ladder,PBEM,2K games,firaxis,civ

- Регистрация
- Помощь
- Запомнить?

# Регистрация

### Обязательная информация

Имя:

Пожалуйста, укажите здесь имя пользователя, под которым вы будете входить, и вас будут знать на этом сайте.

- Пароль:
- Подтвердите пароль:

Введите свой пароль. Пароль чувствителен к регистру букв.

- Email:
- Подтвердите email:

Введите правильный адрес электронной почты.

Случайный вопрос:

Напиши какой сейчас год (покажи что ты человек)

### Требуется дополнительная информация (настройки)

Напиши какой сейчас год (покажи что ты человек):

Проверка при регистрации

### Дополнительная информация

Реферер:

Если вы пришли на этот сайт по совету одного из участников, то, пожалуйста, введите его имя пользователя.

Часовой пояс:

Время на сайте может быть выставлено в соответствии с тем, где вы находитесь. Выберите свой часовой пояс из списка ниже.

Опции перехода на летнее/зимнее время (DST):

Учитывать переход на летнее или зимнее время (DST).

Получать электронные письма...

- Получать электронные письма от администрации
- Получать электронные письма от других участников

Время от времени администрация и/или другие пользователи могут посылать вам сообщения по электронной почте. Если вы не хотите получать сообщения от тех и/или других, отключите соответствующие опции.

Steam:

Имя профиля Steam

Пол:

## Правила форума

Для продолжения регистрации вы должны согласиться со следующими правилами:

Правила форума

Регистрация на сайте абсолютно бесплатна! Настоятельно рекомендуем вам ознакомиться с правилами нашего проекта. Если вы согласны со всеми условиями, поставьте галочку рядом с "Я обязуюсь исполнять установленные правила" и нажмите кнопку "Завершить регистрацию". Если вы передумали регистрироваться, нажмите здесь, чтобы вернуться на главную страницу.

Хотя модераторы и администраторы, обслуживающие civ.club, стараются удалять все оскорбительные и некорректные сообщения из разделов на форуме, всё равно все сообщения просмотреть невозможно. Сообщения отражают точку зрения только автора, и никак не руководства сайта, соответственно, только автор несёт ответственность за содержание сообщения.

Соглашаясь с нашими правилами, вы обязуетесь выполнять требования сайта в целом, а также требования законодательства РФ.

Администрация сайта оставляет за собой право удалять, изменять, переносить или закрывать любую тему или сообщение по своему усмотрению.

Я обязуюсь исполнять установленные правила, посещая civ.club.